@@ -1,5 +1,6 @@
 import os
 import json
+import shutil
 import subprocess
 import sys
 import asyncio
@@ -14,7 +15,7 @@ import socket
 import websockets
 from websockets.exceptions import InvalidStatusCode, ConnectionClosed, ConnectionClosedOK
 from logging.handlers import TimedRotatingFileHandler
-from tickerdax.constants import Envs, KeyTypes, NAME, URL, GLOBAL_INSTANCE_NAME
+from tickerdax.constants import Envs, KeyTypes, NAME, URL, GLOBAL_INSTANCE_NAME, DEFAULT_REDIS_CONFIG
 from docker.errors import DockerException
 from datetime import datetime, timedelta, timezone
 from tickerdax import formatting
@@ -268,6 +269,8 @@ class TickerDax:
         # if in the official docker image, try starting redis manually and
         if os.environ.get(Envs.OFFICIAL_DOCKER_IMAGE.value) and attempts < 1:
             os.makedirs(self._cache_folder, exist_ok=True)
+            if not os.path.exists(DEFAULT_REDIS_CONFIG):
+                shutil.copy(DEFAULT_REDIS_CONFIG, os.path.join(self._cache_folder, 'redis.conf'))
             try:
                 subprocess.Popen(
                     f'redis-server {self._cache_folder} --port {self._redis_host_port}',
